Crate vortex_fsst

Crate vortex_fsst 

An array that uses the Fast Static Symbol Table compression scheme to compress string arrays.

FSST arrays can generally compress string data up to 2x through the use of string tables. The string table is static for an entire array, and occupies up to 2048 bytes of buffer space. Thus, FSST is only worth reaching for when dealing with larger arrays of potentially hundreds of kilobytes or more.

Structs

FSST
FSSTData
The inner data for an FSST-compressed array.
FSSTMetadata
FSSTSlots
FSSTSlotsView
Borrowed view of FSSTSlots.

Traits

FSSTArrayExt
FSSTArraySlotsExt
Typed array accessors for FSST.

Functions

fsst_compress
Compress a string array using FSST.
fsst_train_compressor
Train an FSST Compressor from a string array’s non-null rows.
initialize
Initialize FSST encoding in the given session.

Type Aliases

FSSTArray
A FSST-encoded Vortex array.