pub struct FSSTData { /* private fields */ }Expand description
The inner data for an FSST-compressed array.
Holds the FSST symbol table (symbols + symbol_lengths) and the raw compressed
codes bytes buffer. The codes offsets and validity live in the outer array’s slots
(slots 1 and 2 respectively).
A full VarBinArray representing the codes can be reconstructed on demand via
FSSTArrayExt::codes(), combining this buffer with the offsets/validity from slots.
Implementations
Sourceimpl FSSTData
impl FSSTData
Sourcepub fn try_new(
symbols: Buffer<Symbol>,
symbol_lengths: Buffer<u8>,
codes_bytes: BufferHandle,
len: usize,
) -> VortexResult<Self>
pub fn try_new( symbols: Buffer<Symbol>, symbol_lengths: Buffer<u8>, codes_bytes: BufferHandle, len: usize, ) -> VortexResult<Self>
Build FSST data from a set of symbols, symbol_lengths, and compressed codes bytes.
Symbols are 8-bytes and can represent short strings, each of which is assigned a code.
The codes_bytes buffer contains the concatenated compressed bytecodes for all elements.
Each element’s compressed bytecodes are a sequence of 8-bit codes, where each code
corresponds either to a symbol or to the “escape code” (which tells the decoder to
emit the following byte without doing a table lookup).
The offsets and validity for the codes are stored in the array’s slots, not here.
Use FSSTArrayExt::codes() to reconstruct a full VarBinArray.
pub fn validate( &self, dtype: &DType, len: usize, slots: &[Option<ArrayRef>], ) -> VortexResult<()>
Sourcepub fn symbol_lengths(&self) -> &Buffer<u8>
pub fn symbol_lengths(&self) -> &Buffer<u8>
Access the symbol lengths array.
Sourcepub fn codes_bytes_handle(&self) -> &BufferHandle
pub fn codes_bytes_handle(&self) -> &BufferHandle
Access the compressed codes bytes buffer handle (may be on host or device).
Sourcepub fn codes_bytes(&self) -> &ByteBuffer
pub fn codes_bytes(&self) -> &ByteBuffer
Access the compressed codes bytes on the host.
Sourcepub fn decompressor(&self) -> Decompressor<'_>
pub fn decompressor(&self) -> Decompressor<'_>
Build a Decompressor that can be used to decompress values from
this array.
Sourcepub fn compressor(&self) -> &Compressor
pub fn compressor(&self) -> &Compressor
Retrieves the FSST compressor.