FSSTArrayExt

Trait FSSTArrayExt 

pub trait FSSTArrayExt: TypedArrayRef<FSST> {
    // Provided methods
    fn uncompressed_lengths(&self) -> &ArrayRef { ... }
    fn uncompressed_lengths_dtype(&self) -> &DType { ... }
    fn codes(&self) -> VarBinArray { ... }
    fn codes_dtype(&self) -> DType { ... }
}

Provided Methods

fn uncompressed_lengths(&self) -> &ArrayRef

fn uncompressed_lengths_dtype(&self) -> &DType

fn codes(&self) -> VarBinArray

Reconstruct a VarBinArray for the compressed codes by combining the bytes from FSSTData with the offsets and validity stored in the array’s slots.

fn codes_dtype(&self) -> DType

Get the DType of the codes array.

Implementors