An array that uses the Fast Static Symbol Table compression scheme to compress string arrays.
FSST arrays can generally compress string data up to 2x through the use of string tables. The string table is static for an entire array, and occupies up to 2048 bytes of buffer space. Thus, FSST is only worth reaching for when dealing with larger arrays of potentially hundreds of kilobytes or more.
Structs
- FSST
- FSST
Data - The inner data for an FSST-compressed array.
- FSST
Metadata
Traits
Functions
- fsst_
compress - Compress a string array using FSST.
- fsst_
train_ compressor - Train an FSST
Compressorfrom a string array’s non-null rows. - initialize
- Initialize FSST encoding in the given session.